#!/bin/bash

PERFTEST_CONFIG_FILE=adsperftest.conf
BELKA_CONFIG_DIR=/etc/belka
BELKA_JAR_DIR=/home/five9inf/belka/jars
FLINK_JAR_PATH=/home/five9inf/flink/lib
PATH_SEPARATOR=":"

echo "Aggregated Data Storage performance test app"
echo "More details can be found on http://wiki.five9.com/twiki/bin/view/Main/DataServAggregatedDataStorage"

if [ "$1" == "--help" ]; then
    echo "Put performance test parameters to configuration file $PERFTEST_CONFIG_FILE"
    echo "See config file comments for details"
    exit 0
fi

if [ "$(expr substr $(uname -s) 1 10)" == "MINGW32_NT" ]; then
    echo "Running under windows/32: config file and jars will be taken from current directory"
    BELKA_CONFIG_DIR=.
    BELKA_JAR_DIR=.
    FLINK_JAR_PATH=.
    PATH_SEPARATOR=";"
elif [ "$(expr substr $(uname -s) 1 10)" == "MINGW64_NT" ]; then
    echo "Running under windows/64: config file and jars will be taken from current directory"
    BELKA_CONFIG_DIR=.
    BELKA_JAR_DIR=.
    FLINK_JAR_PATH=.
    PATH_SEPARATOR=";"
fi


#checking for configuration file
if [ -f ./$PERFTEST_CONFIG_FILE ]; then
    PERFTEST_CONFIG_FILE=./$PERFTEST_CONFIG_FILE
elif [ -f $BELKA_CONFIG_DIR/$PERFTEST_CONFIG_FILE ]; then
    PERFTEST_CONFIG_FILE=$BELKA_CONFIG_DIR/$PERFTEST_CONFIG_FILE
else
    echo "Configuration file $PERFTEST_CONFIG_FILE is not found (paths: current directory, $BELKA_CONFIG_DIR) - use ${PERFTEST_CONFIG_FILE}.sample as a base"
    exit 1
fi

echo "Using configuration file $PERFTEST_CONFIG_FILE"

. ${PERFTEST_CONFIG_FILE}

JAR_FILE_MASK="$FLINK_JAR_PATH/slf4j-log4j12*.jar"
FOUND_JAR_FILES=( $JAR_FILE_MASK )
SLF4J_JAR=${FOUND_JAR_FILES[0]}

JAR_FILE_MASK="$FLINK_JAR_PATH/flink-dist*.jar"
FOUND_JAR_FILES=( $JAR_FILE_MASK )
FLINKDIST_JAR=${FOUND_JAR_FILES[0]}

JAR_FILE_MASK="$FLINK_JAR_PATH/log4j*.jar"
FOUND_JAR_FILES=( $JAR_FILE_MASK )
LOG4J_JAR=${FOUND_JAR_FILES[0]}


if [ ! -f $SLF4J_JAR ]; then
    echo "slf4j jar file is not found in $FLINK_JAR_PATH directory"
    exit 1
fi

if [ ! -f $FLIKDIST_JAR ]; then
    echo "flink-dist jar file is not found in $FLINK_JAR_PATH directory"
    exit 1
fi

if [ ! -f $LOG4J_JAR ]; then
    echo "log4j jar file is not found in $FLINK_JAR_PATH directory"
    exit 1
fi


JAR_NAME=flink-aggregation.jar

if [ -f $BELKA_JAR_DIR/$JAR_NAME ]; then
    JAR_NAME=$BELKA_JAR_DIR/$JAR_NAME
else
    echo "JAR file $JAR_NAME is not found in $BELKA_JAR_DIR directory"
    exit 1
fi

JARS=${JAR_NAME}${PATH_SEPARATOR}${SLF4J_JAR}${PATH_SEPARATOR}${FLINKDIST_JAR}${PATH_SEPARATOR}${LOG4J_JAR}
echo classpath=$JARS

echo "Running PerfTest"

java -cp ${JARS} com.five9.aggregation.storage.PerfTest \
--host=$db_hostname --port=$db_port --user=$db_user --password=$db_password \
--log=$log_file --cleanup=$param_cleanup \
--use-myisam=$param_use_myisam --read-threads=$param_read_threads --write-threads=$param_write_threads \
--interval-count=$param_interval_count --read-requests-per-interval=$param_requests_per_interval \
--read-after-write=$param_read_after_write --max-events-per-group=$param_max_events_per_group \
--min-groups-per-interval=$param_min_groups_per_interval --max-groups-per-interval=$param_max_groups_per_interval \
--attibute-partitions=$param_attibute_partitions --metric-partitions=$param_metric_partitions \
--db-name-prefix=$param_db_name_prefix --org-id=$param_org_id
